# -----------------------------------------------------------------------------
# Copyright © 2009- The Spyder Development Team
#
# Licensed under the terms of the MIT License
# (see LICENSE.txt for details)
# -----------------------------------------------------------------------------

"""Provides Qt3DRender classes and functions."""

from . import (
    PYQT5,
    PYQT6,
    PYSIDE2,
    PYSIDE6,
    QtModuleNotInstalledError,
)

if PYQT5:
    try:
        from PyQt5.Qt3DRender import *
    except ModuleNotFoundError as error:
        raise QtModuleNotInstalledError(
            name="Qt3DRender",
            missing_package="PyQt3D",
        ) from error
elif PYQT6:
    try:
        from PyQt6.Qt3DRender import *
    except ModuleNotFoundError as error:
        raise QtModuleNotInstalledError(
            name="Qt3DRender",
            missing_package="PyQt6-3D",
        ) from error
elif PYSIDE2:
    # https://bugreports.qt.io/projects/PYSIDE/issues/PYSIDE-1026
    import inspect

    import PySide2.Qt3DRender as __temp

    for __name in inspect.getmembers(__temp.Qt3DRender):
        globals()[__name[0]] = __name[1]
elif PYSIDE6:
    # https://bugreports.qt.io/projects/PYSIDE/issues/PYSIDE-1026
    import inspect

    import PySide6.Qt3DRender as __temp

    for __name in inspect.getmembers(__temp.Qt3DRender):
        globals()[__name[0]] = __name[1]



import pytest

from qtpy.tests.utils import pytest_importorskip


def test_qtpdf():
    """Test the qtpy.QtPdf namespace"""
    QtPdf = pytest_importorskip("qtpy.QtPdf")

    assert QtPdf.QPdfDocument is not None
    assert QtPdf.QPdfLink is not None
    assert QtPdf.QPdfSelection is not None



import contextlib
import platform
import sys
from unittest import mock

import pytest

from qtpy import PYQT5, PYSIDE2


@pytest.mark.skipif(not PYQT5, reason="Targeted to PyQt5")
@mock.patch.object(platform, "mac_ver")
def test_qt59_exception(mac_ver, monkeypatch):
    # Remove qtpy to reimport it again
    with contextlib.suppress(KeyError):
        del sys.modules["qtpy"]

    # Patch stdlib to emulate a macOS system
    monkeypatch.setattr("sys.platform", "darwin")
    mac_ver.return_value = ("10.9.2",)

    # Patch Qt version
    monkeypatch.setattr("PyQt5.QtCore.QT_VERSION_STR", "5.9.1")

    # This should raise an Exception
    with pytest.raises(Exception) as e:
        import qtpy

    assert "10.10" in str(e.value)
    assert "5.9" in str(e.value)


@pytest.mark.skipif(not PYQT5, reason="Targeted to PyQt5")
@mock.patch.object(platform, "mac_ver")
def test_qt59_no_exception(mac_ver, monkeypatch):
    # Remove qtpy to reimport it again
    with contextlib.suppress(KeyError):
        del sys.modules["qtpy"]

    # Patch stdlib to emulate a macOS system
    monkeypatch.setattr("sys.platform", "darwin")
    mac_ver.return_value = ("10.10.1",)

    # Patch Qt version
    monkeypatch.setattr("PyQt5.QtCore.QT_VERSION_STR", "5.9.5")

    # This should not raise an Exception
    try:
        import qtpy
    except Exception:  # noqa: BLE001
        pytest.fail("Error!")


@pytest.mark.skipif(
    not (PYQT5 or PYSIDE2),
    reason="Targeted to PyQt5 or PySide2",
)
@mock.patch.object(platform, "mac_ver")
def test_qt511_exception(mac_ver, monkeypatch):
    # Remove qtpy to reimport it again
    with contextlib.suppress(KeyError):
        del sys.modules["qtpy"]

    # Patch stdlib to emulate a macOS system
    monkeypatch.setattr("sys.platform", "darwin")
    mac_ver.return_value = ("10.10.3",)

    # Patch Qt version
    if PYQT5:
        monkeypatch.setattr("PyQt5.QtCore.QT_VERSION_STR", "5.11.1")
    else:
        monkeypatch.setattr("PySide2.QtCore.__version__", "5.11.1")

    # This should raise an Exception
    with pytest.raises(Exception) as e:
        import qtpy

    assert "10.11" in str(e.value)
    assert "5.11" in str(e.value)


@pytest.mark.skipif(
    not (PYQT5 or PYSIDE2),
    reason="Targeted to PyQt5 or PySide2",
)
@mock.patch.object(platform, "mac_ver")
def test_qt511_no_exception(mac_ver, monkeypatch):
    # Remove qtpy to reimport it again
    with contextlib.suppress(KeyError):
        del sys.modules["qtpy"]

    # Patch stdlib to emulate a macOS system
    monkeypatch.setattr("sys.platform", "darwin")
    mac_ver.return_value = ("10.13.2",)

    # Patch Qt version
    if PYQT5:
        monkeypatch.setattr("PyQt5.QtCore.QT_VERSION_STR", "5.11.1")
    else:
        monkeypatch.setattr("PySide2.QtCore.__version__", "5.11.1")

    # This should not raise an Exception
    try:
        import qtpy
    except Exception:  # noqa: BLE001
        pytest.fail("Error!")



import pytest

from qtpy.tests.utils import pytest_importorskip


def test_qtwebenginecore():
    """Test the qtpy.QtWebEngineCore namespace"""
    QtWebEngineCore = pytest_importorskip("qtpy.QtWebEngineCore")

    assert QtWebEngineCore.QWebEngineHttpRequest is not None



"""Test the QtPy CLI."""

import subprocess
import sys
import textwrap

import pytest

import qtpy

SUBCOMMANDS = [
    [],
    ["mypy-args"],
]


@pytest.mark.parametrize(
    argnames=["subcommand"],
    argvalues=[[subcommand] for subcommand in SUBCOMMANDS],
    ids=[" ".join(subcommand) for subcommand in SUBCOMMANDS],
)
def test_cli_help_does_not_fail(subcommand):
    subprocess.run(
        [sys.executable, "-m", "qtpy", *subcommand, "--help"],
        check=True,
    )


def test_cli_version():
    output = subprocess.run(
        [sys.executable, "-m", "qtpy", "--version"],
        capture_output=True,
        check=True,
        encoding="utf-8",
    )
    assert output.stdout.strip().split()[-1] == qtpy.__version__


def test_cli_mypy_args():
    output = subprocess.run(
        [sys.executable, "-m", "qtpy", "mypy-args"],
        capture_output=True,
        check=True,
        encoding="utf-8",
    )

    if qtpy.PYQT5:
        expected = " ".join(
            [
                "--always-true=PYQT5",
                "--always-false=PYSIDE2",
                "--always-false=PYQT6",
                "--always-false=PYSIDE6",
            ],
        )
    elif qtpy.PYSIDE2:
        expected = " ".join(
            [
                "--always-false=PYQT5",
                "--always-true=PYSIDE2",
                "--always-false=PYQT6",
                "--always-false=PYSIDE6",
            ],
        )
    elif qtpy.PYQT6:
        expected = " ".join(
            [
                "--always-false=PYQT5",
                "--always-false=PYSIDE2",
                "--always-true=PYQT6",
                "--always-false=PYSIDE6",
            ],
        )
    elif qtpy.PYSIDE6:
        expected = " ".join(
            [
                "--always-false=PYQT5",
                "--always-false=PYSIDE2",
                "--always-false=PYQT6",
                "--always-true=PYSIDE6",
            ],
        )
    else:
        pytest.fail("No Qt bindings detected")

    assert output.stdout.strip() == expected.strip()


def test_cli_pyright_config():
    output = subprocess.run(
        [sys.executable, "-m", "qtpy", "pyright-config"],
        capture_output=True,
        check=True,
        encoding="utf-8",
    )

    if qtpy.PYQT5:
        expected = textwrap.dedent(
            """
            pyrightconfig.json:
            {"defineConstant": {"PYQT5": true, "PYSIDE2": false, "PYQT6": false, "PYSIDE6": false}}

            pyproject.toml:
            [tool.pyright.defineConstant]
            PYQT5 = true
            PYSIDE2 = false
            PYQT6 = false
            PYSIDE6 = false
        """,
        )
    elif qtpy.PYSIDE2:
        expected = textwrap.dedent(
            """
            pyrightconfig.json:
            {"defineConstant": {"PYQT5": false, "PYSIDE2": true, "PYQT6": false, "PYSIDE6": false}}

            pyproject.toml:
            [tool.pyright.defineConstant]
            PYQT5 = false
            PYSIDE2 = true
            PYQT6 = false
            PYSIDE6 = false
        """,
        )
    elif qtpy.PYQT6:
        expected = textwrap.dedent(
            """
            pyrightconfig.json:
            {"defineConstant": {"PYQT5": false, "PYSIDE2": false, "PYQT6": true, "PYSIDE6": false}}

            pyproject.toml:
            [tool.pyright.defineConstant]
            PYQT5 = false
            PYSIDE2 = false
            PYQT6 = true
            PYSIDE6 = false
        """,
        )
    elif qtpy.PYSIDE6:
        expected = textwrap.dedent(
            """
            pyrightconfig.json:
            {"defineConstant": {"PYQT5": false, "PYSIDE2": false, "PYQT6": false, "PYSIDE6": true}}

            pyproject.toml:
            [tool.pyright.defineConstant]
            PYQT5 = false
            PYSIDE2 = false
            PYQT6 = false
            PYSIDE6 = true
        """,
        )
    else:
        pytest.fail("No valid API to test")

    assert output.stdout.strip() == expected.strip()



def test_qtwebchannel():
    """Test the qtpy.QtWebChannel namespace"""
    from qtpy import QtWebChannel

    assert QtWebChannel.QWebChannel is not None
    assert QtWebChannel.QWebChannelAbstractTransport is not None



"""Test QtSql."""

import sys

import pytest

from qtpy import PYSIDE2, PYSIDE_VERSION, QtSql


@pytest.fixture
def database_connection():
    """Create a database connection"""
    connection = QtSql.QSqlDatabase.addDatabase("QSQLITE")
    yield connection
    connection.close()


def test_qtsql():
    """Test the qtpy.QtSql namespace"""
    assert QtSql.QSqlDatabase is not None
    assert QtSql.QSqlDriverCreatorBase is not None
    assert QtSql.QSqlDriver is not None
    assert QtSql.QSqlError is not None
    assert QtSql.QSqlField is not None
    assert QtSql.QSqlIndex is not None
    assert QtSql.QSqlQuery is not None
    assert QtSql.QSqlRecord is not None
    assert QtSql.QSqlResult is not None
    assert QtSql.QSqlQueryModel is not None
    assert QtSql.QSqlRelationalDelegate is not None
    assert QtSql.QSqlRelation is not None
    assert QtSql.QSqlRelationalTableModel is not None
    assert QtSql.QSqlTableModel is not None

    # Following modules are not (yet) part of any wrapper:
    # QSqlDriverCreator, QSqlDriverPlugin


@pytest.mark.skipif(
    sys.platform == "win32" and PYSIDE2 and PYSIDE_VERSION.startswith("5.13"),
    reason="SQLite driver unavailable on PySide 5.13.2 with Windows",
)
def test_qtsql_members_aliases(database_connection):
    """
    Test aliased methods over qtpy.QtSql members including:

    * qtpy.QtSql.QSqlDatabase.exec_
    * qtpy.QtSql.QSqlQuery.exec_
    * qtpy.QtSql.QSqlResult.exec_
    """
    assert QtSql.QSqlDatabase.exec_ is not None
    assert QtSql.QSqlQuery.exec_ is not None
    assert QtSql.QSqlResult.exec_ is not None

    assert database_connection.open()
    database_connection.setDatabaseName("test.sqlite")
    QtSql.QSqlDatabase.exec_(
        database_connection,
        """
        CREATE TABLE test (
            id INTEGER PRIMARY KEY AUTOINCREMENT UNIQUE NOT NULL,
            name VARCHAR(40) NOT NULL
        )
        """,
    )

    # Created table 'test' and 'sqlite_sequence'
    assert len(database_connection.tables()) == 2

    insert_table_query = QtSql.QSqlQuery()
    assert insert_table_query.exec_(
        """
        INSERT INTO test (name) VALUES (
            "TESTING"
        )
        """,
    )

    select_table_query = QtSql.QSqlQuery()
    select_table_query.prepare(
        """
        SELECT * FROM test
        """,
    )
    select_table_query.exec_()
    record = select_table_query.record()
    assert not record.isEmpty()



"""Utility functions for tests."""

import os

import pytest
from packaging.version import parse


def using_conda():
    return os.environ.get("USE_CONDA", "Yes") == "Yes"


def not_using_conda():
    return os.environ.get("USE_CONDA", "No") == "No"


def pytest_importorskip(module, **kwargs):
    """
    Skip the test if the module cannot be imported.

    This is a wrapper around `pytest.importorskip` to support using it with
    Python 3.7+. The `exc_type` argument was added in `pytest` 8.2.0.
    See spyder-ide/qtpy#485
    """
    if parse(pytest.__version__) < parse("8.2.0"):
        return pytest.importorskip(module, **kwargs)
    return pytest.importorskip(module, **kwargs, exc_type=ImportError)



# -----------------------------------------------------------------------------
# Copyright © 2014-2015 Colin Duquesnoy
# Copyright © 2009- The Spyder development Team
#
# Licensed under the terms of the MIT License
# (see LICENSE.txt for details)
# -----------------------------------------------------------------------------

"""Provides QtWebEngineWidgets classes and functions."""

from . import (
    PYQT5,
    PYQT6,
    PYSIDE2,
    PYSIDE6,
    QtModuleNotInstalledError,
)

# To test if we are using WebEngine or WebKit
# NOTE: This constant is imported by other projects (e.g. Spyder), so please
# don't remove it.
WEBENGINE = True


if PYQT5:
    try:
        # Based on the work at https://github.com/spyder-ide/qtpy/pull/203
        from PyQt5.QtWebEngineWidgets import (
            QWebEnginePage,
            QWebEngineProfile,
            QWebEngineScript,
            QWebEngineSettings,
            QWebEngineView,
        )
    except ModuleNotFoundError as error:
        raise QtModuleNotInstalledError(
            name="QtWebEngineWidgets",
            missing_package="PyQtWebEngine",
        ) from error
elif PYQT6:
    try:
        from PyQt6.QtWebEngineCore import (
            QWebEnginePage,
            QWebEngineProfile,
            QWebEngineScript,
            QWebEngineSettings,
        )
        from PyQt6.QtWebEngineWidgets import *
    except ModuleNotFoundError as error:
        raise QtModuleNotInstalledError(
            name="QtWebEngineWidgets",
            missing_package="PyQt6-WebEngine",
        ) from error
elif PYSIDE2:
    # Based on the work at https://github.com/spyder-ide/qtpy/pull/203
    from PySide2.QtWebEngineWidgets import (
        QWebEnginePage,
        QWebEngineProfile,
        QWebEngineScript,
        QWebEngineSettings,
        QWebEngineView,
    )
elif PYSIDE6:
    from PySide6.QtWebEngineCore import (
        QWebEnginePage,
        QWebEngineProfile,
        QWebEngineScript,
        QWebEngineSettings,
    )
    from PySide6.QtWebEngineWidgets import *



import sys

import pytest

from qtpy import PYQT6, PYSIDE6
from qtpy.tests.utils import pytest_importorskip, using_conda


@pytest.mark.skipif(
    PYQT6 or PYSIDE6,
    reason="Not available on Qt6-based bindings",
)
@pytest.mark.skipif(
    sys.platform != "darwin" or using_conda(),
    reason="Only available in Qt5 bindings > 5.9 with pip on mac in CIs",
)
def test_qtmacextras():
    """Test the qtpy.QtMacExtras namespace"""
    QtMacExtras = pytest_importorskip("qtpy.QtMacExtras")

    assert QtMacExtras.QMacPasteboardMime is not None
    assert QtMacExtras.QMacToolBar is not None
    assert QtMacExtras.QMacToolBarItem is not None



import pytest
from packaging import version

from qtpy import PYQT5, PYQT6, PYQT_VERSION, PYSIDE6, QtTest


def test_qttest():
    """Test the qtpy.QtTest namespace"""
    assert QtTest.QTest is not None

    if PYQT5 or PYQT6 or PYSIDE6:
        assert QtTest.QSignalSpy is not None

        if (
            (PYQT5 and version.parse(PYQT_VERSION) >= version.parse("5.11"))
            or PYQT6
            or PYSIDE6
        ):
            assert QtTest.QAbstractItemModelTester is not None


@pytest.mark.skipif(
    PYQT5 and PYQT_VERSION.startswith("5.9"),
    reason="A specific setup with at least sip 4.9.9 is needed for PyQt5 5.9.*"
    "to work with scoped enum access",
)
def test_enum_access():
    """Test scoped and unscoped enum access for qtpy.QtTest.*."""
    assert QtTest.QTest.Click == QtTest.QTest.KeyAction.Click



# -----------------------------------------------------------------------------
# Copyright © 2009- The Spyder Development Team
#
# Licensed under the terms of the MIT License
# (see LICENSE.txt for details)
# -----------------------------------------------------------------------------

"""Provides classes and functions specific to macOS and iOS operating systems"""

import sys

from . import (
    PYQT5,
    PYQT6,
    PYSIDE2,
    PYSIDE6,
    QtModuleNotInOSError,
    QtModuleNotInQtVersionError,
)

if sys.platform == "darwin":
    if PYQT5:
        from PyQt5.QtMacExtras import *
    elif PYQT6:
        raise QtModuleNotInQtVersionError(name="QtMacExtras")
    elif PYSIDE2:
        from PySide2.QtMacExtras import *
    elif PYSIDE6:
        raise QtModuleNotInQtVersionError(name="QtMacExtras")
else:
    raise QtModuleNotInOSError(name="QtMacExtras")



import pytest

from qtpy.tests.utils import pytest_importorskip


def test_qtaxcontainer():
    """Test the qtpy.QtAxContainer namespace"""
    QtAxContainer = pytest_importorskip("qtpy.QtAxContainer")

    assert QtAxContainer.QAxSelect is not None
    assert QtAxContainer.QAxWidget is not None



import sys

import pytest

from qtpy import PYQT6, PYSIDE6


def test_qtmultimedia():
    """Test the qtpy.QtMultimedia namespace"""
    from qtpy import QtMultimedia

    assert QtMultimedia.QAudio is not None
    assert QtMultimedia.QAudioInput is not None

    if not (PYSIDE6 or PYQT6):
        assert QtMultimedia.QAbstractVideoBuffer is not None
        assert QtMultimedia.QAudioDeviceInfo is not None
        assert QtMultimedia.QSound is not None



import pytest

from qtpy.tests.utils import pytest_importorskip


def test_qt3dextras():
    """Test the qtpy.Qt3DExtras namespace"""
    Qt3DExtras = pytest_importorskip("qtpy.Qt3DExtras")

    assert Qt3DExtras.QTextureMaterial is not None
    assert Qt3DExtras.QPhongAlphaMaterial is not None
    assert Qt3DExtras.QOrbitCameraController is not None
    assert Qt3DExtras.QAbstractSpriteSheet is not None
    assert Qt3DExtras.QNormalDiffuseMapMaterial is not None
    assert Qt3DExtras.QDiffuseSpecularMaterial is not None
    assert Qt3DExtras.QSphereGeometry is not None
    assert Qt3DExtras.QCuboidGeometry is not None
    assert Qt3DExtras.QForwardRenderer is not None
    assert Qt3DExtras.QPhongMaterial is not None
    assert Qt3DExtras.QSpriteGrid is not None
    assert Qt3DExtras.QDiffuseMapMaterial is not None
    assert Qt3DExtras.QConeGeometry is not None
    assert Qt3DExtras.QSpriteSheetItem is not None
    assert Qt3DExtras.QPlaneGeometry is not None
    assert Qt3DExtras.QSphereMesh is not None
    assert Qt3DExtras.QNormalDiffuseSpecularMapMaterial is not None
    assert Qt3DExtras.QCuboidMesh is not None
    assert Qt3DExtras.QGoochMaterial is not None
    assert Qt3DExtras.QText2DEntity is not None
    assert Qt3DExtras.QTorusMesh is not None
    assert Qt3DExtras.Qt3DWindow is not None
    assert Qt3DExtras.QPerVertexColorMaterial is not None
    assert Qt3DExtras.QExtrudedTextGeometry is not None
    assert Qt3DExtras.QSkyboxEntity is not None
    assert Qt3DExtras.QAbstractCameraController is not None
    assert Qt3DExtras.QExtrudedTextMesh is not None
    assert Qt3DExtras.QCylinderGeometry is not None
    assert Qt3DExtras.QTorusGeometry is not None
    assert Qt3DExtras.QMorphPhongMaterial is not None
    assert Qt3DExtras.QPlaneMesh is not None
    assert Qt3DExtras.QDiffuseSpecularMapMaterial is not None
    assert Qt3DExtras.QSpriteSheet is not None
    assert Qt3DExtras.QConeMesh is not None
    assert Qt3DExtras.QFirstPersonCameraController is not None
    assert Qt3DExtras.QMetalRoughMaterial is not None
    assert Qt3DExtras.QCylinderMesh is not None



#
# Copyright © 2009- The Spyder Development Team
# Licensed under the terms of the MIT License

"""
Compatibility functions
"""
import sys

from . import (
    PYQT5,
    PYQT6,
    PYSIDE2,
    PYSIDE6,
)
from .QtWidgets import QFileDialog

TEXT_TYPES = (str,)


def is_text_string(obj):
    """Return True if `obj` is a text string, False if it is anything else,
    like binary data."""
    return isinstance(obj, str)


def to_text_string(obj, encoding=None):
    """Convert `obj` to (unicode) text string"""
    if encoding is None:
        return str(obj)
    if isinstance(obj, str):
        # In case this function is not used properly, this could happen
        return obj

    return str(obj, encoding)


# =============================================================================
# QVariant conversion utilities
# =============================================================================
PYQT_API_1 = False


def to_qvariant(obj=None):  # analysis:ignore
    """Convert Python object to QVariant
    This is a transitional function from PyQt API#1 (QVariant exist)
    to PyQt API#2 and Pyside (QVariant does not exist)"""
    return obj


def from_qvariant(qobj=None, pytype=None):  # analysis:ignore
    """Convert QVariant object to Python object
    This is a transitional function from PyQt API #1 (QVariant exist)
    to PyQt API #2 and Pyside (QVariant does not exist)"""
    return qobj


# =============================================================================
# Wrappers around QFileDialog static methods
# =============================================================================
def getexistingdirectory(
    parent=None,
    caption="",
    basedir="",
    options=QFileDialog.ShowDirsOnly,
):
    """Wrapper around QtGui.QFileDialog.getExistingDirectory static method
    Compatible with PyQt >=v4.4 (API #1 and #2) and PySide >=v1.0"""
    # Calling QFileDialog static method
    if sys.platform == "win32":
        # On Windows platforms: redirect standard outputs
        _temp1, _temp2 = sys.stdout, sys.stderr
        sys.stdout, sys.stderr = None, None
    try:
        result = QFileDialog.getExistingDirectory(
            parent,
            caption,
            basedir,
            options,
        )
    finally:
        if sys.platform == "win32":
            # On Windows platforms: restore standard outputs
            sys.stdout, sys.stderr = _temp1, _temp2
    if not is_text_string(result):
        # PyQt API #1
        result = to_text_string(result)
    return result


def _qfiledialog_wrapper(
    attr,
    parent=None,
    caption="",
    basedir="",
    filters="",
    selectedfilter="",
    options=None,
):
    if options is None:
        options = QFileDialog.Option(0)

    func = getattr(QFileDialog, attr)

    # Calling QFileDialog static method
    if sys.platform == "win32":
        # On Windows platforms: redirect standard outputs
        _temp1, _temp2 = sys.stdout, sys.stderr
        sys.stdout, sys.stderr = None, None
    result = func(parent, caption, basedir, filters, selectedfilter, options)
    if sys.platform == "win32":
        # On Windows platforms: restore standard outputs
        sys.stdout, sys.stderr = _temp1, _temp2

    output, selectedfilter = result

    # Always returns the tuple (output, selectedfilter)
    return output, selectedfilter


def getopenfilename(
    parent=None,
    caption="",
    basedir="",
    filters="",
    selectedfilter="",
    options=None,
):
    """Wrapper around QtGui.QFileDialog.getOpenFileName static method
    Returns a tuple (filename, selectedfilter) -- when dialog box is canceled,
    returns a tuple of empty strings
    Compatible with PyQt >=v4.4 (API #1 and #2) and PySide >=v1.0"""
    return _qfiledialog_wrapper(
        "getOpenFileName",
        parent=parent,
        caption=caption,
        basedir=basedir,
        filters=filters,
        selectedfilter=selectedfilter,
        options=options,
    )


def getopenfilenames(
    parent=None,
    caption="",
    basedir="",
    filters="",
    selectedfilter="",
    options=None,
):
    """Wrapper around QtGui.QFileDialog.getOpenFileNames static method
    Returns a tuple (filenames, selectedfilter) -- when dialog box is canceled,
    returns a tuple (empty list, empty string)
    Compatible with PyQt >=v4.4 (API #1 and #2) and PySide >=v1.0"""
    return _qfiledialog_wrapper(
        "getOpenFileNames",
        parent=parent,
        caption=caption,
        basedir=basedir,
        filters=filters,
        selectedfilter=selectedfilter,
        options=options,
    )


def getsavefilename(
    parent=None,
    caption="",
    basedir="",
    filters="",
    selectedfilter="",
    options=None,
):
    """Wrapper around QtGui.QFileDialog.getSaveFileName static method
    Returns a tuple (filename, selectedfilter) -- when dialog box is canceled,
    returns a tuple of empty strings
    Compatible with PyQt >=v4.4 (API #1 and #2) and PySide >=v1.0"""
    return _qfiledialog_wrapper(
        "getSaveFileName",
        parent=parent,
        caption=caption,
        basedir=basedir,
        filters=filters,
        selectedfilter=selectedfilter,
        options=options,
    )


# =============================================================================
def isalive(obj):
    """Wrapper around sip.isdeleted and shiboken.isValid which tests whether
    an object is currently alive."""
    if PYQT5 or PYQT6:
        from . import sip

        return not sip.isdeleted(obj)
    if PYSIDE2 or PYSIDE6:
        from . import shiboken

        return shiboken.isValid(obj)
    return None



# -----------------------------------------------------------------------------
# Copyright © 2009- The Spyder Development Team
#
# Licensed under the terms of the MIT License
# (see LICENSE.txt for details)
# -----------------------------------------------------------------------------

"""Provides QtPrintSupport classes and functions."""

from . import PYQT5, PYQT6, PYSIDE2, PYSIDE6

if PYQT5:
    from PyQt5.QtPrintSupport import *
elif PYQT6:
    from PyQt6.QtPrintSupport import *

    QPageSetupDialog.exec_ = lambda self, *args, **kwargs: self.exec(
        *args,
        **kwargs,
    )
    QPrintDialog.exec_ = lambda self, *args, **kwargs: self.exec(
        *args,
        **kwargs,
    )
    QPrintPreviewWidget.print_ = lambda self, *args, **kwargs: self.print(
        *args,
        **kwargs,
    )
elif PYSIDE6:
    from PySide6.QtPrintSupport import *

    # Map DeprecationWarning methods
    QPageSetupDialog.exec_ = lambda self, *args, **kwargs: self.exec(
        *args,
        **kwargs,
    )
    QPrintDialog.exec_ = lambda self, *args, **kwargs: self.exec(
        *args,
        **kwargs,
    )
elif PYSIDE2:
    from PySide2.QtPrintSupport import *
